AdaptiveVideoPlayerPlatform class

Initializes platform-specific video player backends.

Call this method in your main() function before runApp() to enable video playback on Windows and Linux platforms.

This internally uses video_player_media_kit to provide media_kit-based video playback on Linux, and video_player_win for Windows (registered automatically via federated plugins).

Example:

void main() {
  AdaptiveVideoPlayerPlatform.ensureInitialized();
  runApp(MyApp());
}

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

ensureInitialized() → void
Ensures that the video player platform backends are initialized.