PlayerBottomActionsConfig class

Configuration class for player bottom actions styling

Constructors

PlayerBottomActionsConfig({Color progressBarPlayedColor = Colors.red, Color progressBarHandleColor = Colors.redAccent, Color iconColor = Colors.white, Color textColor = Colors.white, TextStyle? timeTextStyle})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
iconColor Color
final
progressBarHandleColor Color
final
progressBarPlayedColor Color
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textColor Color
final
timeTextStyle TextStyle?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited