videos_player library

Classes

AdaptiveVideoPlayer
Adaptive video player that detects and plays both YouTube and normal videos
FullScreenResult
NormalVideoPlayer
NormalVideoPlayerState
PlayerBottomActionsConfig
Configuration class for player bottom actions styling
PlayerPlaybackConfig
Configuration model for YouTube player playback settings
PlayerStyleConfig
Configuration model for YouTube player styling
PlayerTextConfig
Configuration model for YouTube player text/localization
PlayerVisibilityConfig
Configuration model for YouTube player visibility settings
VideoConfig
Configuration model for the adaptive video player
YouTubePlayerConfig
Complete configuration model for YouTube player Combines all configuration aspects into one clean model
YouTubeVideoPlayer
A widget for playing YouTube videos with full YouTube controls Similar to native YouTube app with speed, quality, captions, etc.
YouTubeVideoPlayerState