NormalVideoPlayer class

Inheritance

Constructors

NormalVideoPlayer({Key? key, required String videoSource, bool isFile = false, bool isLive = false, Uint8List? videoBytes, List<VideoQuality>? qualities, VideoQuality? initialQuality, List<SubtitleTrack>? subtitles, SubtitleTrack? initialSubtitle, String? viewerCount, PlayerStyleConfig? styling, PlayerTextConfig? messages, PlayerVisibilityConfig? visibility, PlayerPlaybackConfig? playback, AdaptiveControlsBuilder? controlsBuilder, SubtitleBuilder? subtitleBuilder, void onAnalyticsEvent(String event, Map<String, dynamic> data)?})
const

Properties

controlsBuilder → AdaptiveControlsBuilder?
Custom ui builder for rendering over the video
final
hashCode → int
The hash code for this object.
no setterinherited
initialQuality → VideoQuality?
Initial quality if qualities list is provided
final
initialSubtitle → SubtitleTrack?
Initial subtitle track to activate
final
isFile → bool
final
isLive → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
messages → PlayerTextConfig?
Messages configuration for the video player
final
onAnalyticsEvent → void Function(String event, Map<String, dynamic> data)?
Analytics hook for external tracking of video events
final
playback → PlayerPlaybackConfig?
Playback configuration for the video player
final
qualities → List<VideoQuality>?
External list of qualities / sources for resolution picker
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
styling → PlayerStyleConfig?
Styling configuration for the video player
final
subtitleBuilder → SubtitleBuilder?
Custom builder for subtitles layer
final
subtitles → List<SubtitleTrack>?
External list of subtitle tracks
final
videoBytes → Uint8List?
final
videoSource → String
final
viewerCount → String?
Optional viewer count to display when stream is live
final
visibility → PlayerVisibilityConfig?
Visibility configuration for the video player
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → NormalVideoPlayerState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited