YouTubeVideoPlayer class

A widget for playing YouTube videos with full YouTube controls Similar to native YouTube app with speed, quality, captions, etc.

Uses YouTubePlayerConfig model for all configuration settings. Uses YoutubePlayerCubit for state management between normal and fullscreen modes.

Inheritance

Constructors

YouTubeVideoPlayer({Key? key, required String videoSource, YouTubePlayerConfig config = const YouTubePlayerConfig(), VoidCallback? onEnded})
const

Properties

config YouTubePlayerConfig
Complete player configuration
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onEnded VoidCallback?
Callback when the video ends
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
videoSource String
The YouTube video URL or video ID
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() YouTubeVideoPlayerState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited