YouTubeVideoPlayerState class

Inheritance

Constructors

YouTubeVideoPlayerState()

Properties

context BuildContext
The location in the tree where this widget builds.
no setterinherited
currentPosition Duration
no setter
duration Duration
no setter
hashCode int
The hash code for this object.
no setterinherited
isPlaying bool
no setter
mounted bool
Whether this State object is currently in a tree.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
widget YouTubeVideoPlayer
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant YouTubeVideoPlayer oldWidget) → void
Called whenever the widget configuration changes.
override
dispose() → void
Called when this object is removed from the tree permanently.
override
enterFullScreen() → void
initState() → void
Called when this object is inserted into the tree.
override
loadVideo(String videoSource) → void
mute() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause() → void
play() → void
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
seekTo(Duration position) → void
setPlaybackRate(double rate) → void
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
stop() → void
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
unMute() → void

Operators

operator ==(Object other) bool
The equality operator.
inherited