PlayerPlaybackConfig class
Configuration model for YouTube player playback settings
Constructors
Properties
- allowExternalLinks → bool
-
Whether to allow opening external links (like clicking the YouTube logo) in the system browser
final
- autoPlay → bool
-
Whether to auto-play the video
final
- enableCaption → bool
-
Whether to enable captions
final
- forceDesktopMode → bool
-
Whether to force the player to behave like a desktop player on mobile.
This will use the WebView player instead of the native YouTube player on mobile.
final
- forceHD → bool
-
Whether to force HD quality
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- loop → bool
-
Whether to loop the video
final
- mute → bool
-
Whether to mute the video initially
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{bool? autoPlay, bool? loop, bool? mute, bool? forceHD, bool? enableCaption, bool? forceDesktopMode, bool? allowExternalLinks}) → PlayerPlaybackConfig - Creates a copy with updated values
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited