PlayerStyleConfig class
Configuration model for YouTube player styling
Constructors
- PlayerStyleConfig({Color progressBarPlayedColor = Colors.red, Color progressBarHandleColor = Colors.redAccent, Color loadingIndicatorColor = const Color(0xFFFF0000), Color errorIconColor = const Color(0xFFFF0000), Color iconColor = Colors.white, Color textColor = Colors.white, Color backgroundColor = const Color(0xFF1D1D1D), Color settingsBackgroundColor = const Color(0xFF1D1D1D), Color settingItemBackgroundColor = const Color(0xFF0D0D0D), Color? switchInactiveThumbColor, Color? switchInactiveTrackColor, TextStyle? timeTextStyle, TextStyle? settingsTitleStyle, TextStyle? settingItemTextStyle, TextStyle? errorTextStyle})
-
const
Properties
- backgroundColor → Color
-
Background color for player
final
- errorIconColor → Color
-
Error icon color
final
- errorTextStyle → TextStyle?
-
Text style for error message
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconColor → Color
-
Icon color for controls
final
- loadingIndicatorColor → Color
-
Loading indicator color
final
- progressBarHandleColor → Color
-
Progress bar handle color
final
- progressBarPlayedColor → Color
-
Progress bar played color
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- settingItemBackgroundColor → Color
-
Background color for setting items
final
- settingItemTextStyle → TextStyle?
-
Text style for setting items
final
- settingsBackgroundColor → Color
-
Background color for settings sheet
final
- settingsTitleStyle → TextStyle?
-
Text style for settings title
final
- switchInactiveThumbColor → Color?
-
Switch inactive thumb color
final
- switchInactiveTrackColor → Color?
-
Switch inactive track color
final
- textColor → Color
-
Text color for time displays
final
- timeTextStyle → TextStyle?
-
Text style for time displays
final
Methods
-
copyWith(
{Color? progressBarPlayedColor, Color? progressBarHandleColor, Color? loadingIndicatorColor, Color? errorIconColor, Color? iconColor, Color? textColor, Color? backgroundColor, Color? settingsBackgroundColor, Color? settingItemBackgroundColor, Color? switchInactiveThumbColor, Color? switchInactiveTrackColor, TextStyle? timeTextStyle, TextStyle? settingsTitleStyle, TextStyle? settingItemTextStyle, TextStyle? errorTextStyle}) → PlayerStyleConfig - Creates a copy with updated values
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited