PlayerVisibilityConfig class
Configuration model for YouTube player visibility settings
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showAutoPlaySetting → bool
-
Whether to show auto play setting in settings sheet
final
- showCaptionsSetting → bool
-
Whether to show enable captions setting in settings sheet
final
- showControls → bool
-
Whether to show video controls (native YouTube controls)
final
- showForceHDSetting → bool
-
Whether to show force HD quality setting in settings sheet
final
- showFullscreenButton → bool
-
Whether to show fullscreen button
final
- showLoopSetting → bool
-
Whether to show loop video setting in settings sheet
final
- showMuteSetting → bool
-
Whether to show mute audio setting in settings sheet
final
- showSettingsButton → bool
-
Whether to show settings button
final
Methods
-
copyWith(
{bool? showControls, bool? showFullscreenButton, bool? showSettingsButton, bool? showAutoPlaySetting, bool? showLoopSetting, bool? showForceHDSetting, bool? showCaptionsSetting, bool? showMuteSetting}) → PlayerVisibilityConfig - Creates a copy with updated values
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited