YouTubePlayerConfig class
Complete configuration model for YouTube player Combines all configuration aspects into one clean model
Constructors
- YouTubePlayerConfig({PlayerStyleConfig style = const PlayerStyleConfig(), PlayerTextConfig text = const PlayerTextConfig(), PlayerVisibilityConfig visibility = const PlayerVisibilityConfig(), PlayerPlaybackConfig playback = const PlayerPlaybackConfig(), String? videoId})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- playback → PlayerPlaybackConfig
-
Playback configuration
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → PlayerStyleConfig
-
Styling configuration
final
- text → PlayerTextConfig
-
Text/localization configuration
final
- videoId → String?
-
final
- visibility → PlayerVisibilityConfig
-
Visibility configuration
final
Methods
-
copyWith(
{PlayerStyleConfig? style, PlayerTextConfig? text, PlayerVisibilityConfig? visibility, PlayerPlaybackConfig? playback}) → YouTubePlayerConfig - Creates a copy with updated values
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultConfig → const YouTubePlayerConfig
- Default configuration