NormalVideoPlayer class

Stub for NormalVideoPlayer — used on platforms where video_player is not available.

Inheritance

Constructors

NormalVideoPlayer({Key? key, required String videoSource, bool isFile = false, Uint8List? videoBytes, PlayerStyleConfig? styling, PlayerTextConfig? messages, PlayerVisibilityConfig? visibility, PlayerPlaybackConfig? playback})
const

Properties

currentPosition Duration
no setter
duration Duration
no setter
hashCode int
The hash code for this object.
no setterinherited
isFile bool
final
isPlaying bool
no setter
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
messages PlayerTextConfig?
final
playback PlayerPlaybackConfig?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
styling PlayerStyleConfig?
final
videoBytes Uint8List?
final
videoSource String
final
visibility PlayerVisibilityConfig?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause() → void
play() → void
seekTo(Duration position) → void
setPlaybackSpeed(double speed) → void
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited